import React from "react";
import { Layout, Loading } from "./components";
import { withRouter } from "react-router-dom";
import socket from "./socket";

const initialState = { loading: true };

class App extends React.Component {
  initializeSocket() {
    socket.on("connect", () => {
      if (!socket.id) console.log("no websocket connection");
      else console.log("my socketId:", socket.id);
    });
    socket.on("welcome", message => {
      this.setState({ loading: false, message });
    });
  }

  async fetchData() {
    // initial axios requests go here
    this.setState({ loading: false });
  }

  /** RENDER FUNCTIONS **/
  renderLoading() {
    return <Loading />;
  }
  renderError() {
    if (this.state.showModal === "Error") return;
    this.setShowModal("Error");
  }
  renderApp() {
    const message = this.state.message || "Fresh and clean.";
    return (
      <div className="w-100 h-100 d-flex flex-grow-1 align-items-center justify-content-center">
        <h1>{message}</h1>
      </div>
    );
  }
  render() {
    if (this.state.loading) return this.renderLoading();
    if (this.state.error) this.renderError();
    if (this.state.component === "layout") return <Layout {...this.state} />;
    return this.renderApp();
  }

  componentDidMount() {
    this.initializeSocket();
    //this.fetchData();
  }
  componentWillUnmount() {
    console.log("unmounting...");
  }
  constructor() {
    super();
    this.state = initialState;
  }
}

export default withRouter(App);
